@@ -2,9 +2,9 @@
 rm(list = ls())
 library(car)
 library(broom)
+library(mosaic)
 library(tidyverse)
 library(ggfortify)
-library(mosaic)
 library(huxtable)
 library(jtools)
 library(latex2exp)
@@ -15,10 +15,9 @@ library(sjmisc)
 
 theme_set(sjPlot::theme_sjplot2(base_size = 10))
 theme_update(legend.position = "top")
-# options('huxtable.knit_print_df' = FALSE)
-options('huxtable.knit_print_df_theme' = theme_article)
+options('huxtable.knit_print_df' = FALSE)
 options('huxtable.autoformat_number_format' = list(numeric = "%5.2f"))
-knitr::opts_chunk$set(collapse = TRUE, comment = NA)
+knitr::opts_chunk$set(comment = NA)
 
 ## -----------------------------------------------------------------------------
 data(birthwt, package = "MASS")
@@ -42,34 +41,45 @@ birthwt %>%
     SD = sd(bwt, na.rm = TRUE),
     Median = median(bwt, na.rm = TRUE),
     CV = rel_dis(bwt)
-  ) 
+  ) %>%
+  as_hux() %>% theme_pubh(1)
 
 ## -----------------------------------------------------------------------------
 birthwt %>%
-  gen_bst_df(bwt ~ race|smoke)
+  box_plot(bwt ~ smoke, fill = ~ race) %>%
+  axis_labs()
 
 ## -----------------------------------------------------------------------------
 birthwt %>%
-  bar_error(bwt ~ race, fill = ~ smoke) %>%
-  axis_labs() %>%
-  gf_labs(fill = "Smoking status:")
+  gen_bst_df(bwt ~ race|smoke) %>%
+  as_hux() %>% theme_pubh(1)
 
 ## -----------------------------------------------------------------------------
 model_norm <- lm(bwt ~ smoke + race, data = birthwt)
 
 ## -----------------------------------------------------------------------------
-model_norm %>% Anova() %>% tidy()
-
-## -----------------------------------------------------------------------------
-model_norm %>% tidy()
+model_norm %>% Anova()
 
 ## -----------------------------------------------------------------------------
 model_norm %>% 
-  glm_coef(labels = model_labels(model_norm))
+  summ(confint = TRUE, model.info = FALSE)
+
+## -----------------------------------------------------------------------------
+model_norm %>% 
+  glm_coef(labels = model_labels(model_norm)) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_norm), font_size = 9)
 
 ## -----------------------------------------------------------------------------
 model_norm %>%
-  glm_coef(se_rob = TRUE, labels = model_labels(model_norm))
+  glm_coef(se_rob = TRUE, labels = model_labels(model_norm)) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(paste(
+    get_r2(model_norm), "\n",
+    "CIs and p-values estimated with robust standard errors."),
+    font_size = 9)
 
 ## -----------------------------------------------------------------------------
 model_norm %>% glance()
@@ -94,18 +104,28 @@ diet <- diet %>%
     )
 
 ## -----------------------------------------------------------------------------
-diet %>% estat(~ fibre|chd)
+diet %>% estat(~ fibre|chd) %>%
+  as_hux() %>% theme_pubh(1)
 
-## ----warning=FALSE------------------------------------------------------------
-diet %>%
-  gf_boxploth(chd ~ fibre, fill = "indianred3", alpha = 0.7) %>%
+## -----------------------------------------------------------------------------
+diet %>% na.omit() %>%
+  copy_labels(diet) %>%
+  box_plot(fibre ~ chd) %>%
   axis_labs()
 
 ## -----------------------------------------------------------------------------
 model_binom <- glm(chd ~ fibre, data = diet, family = binomial)
 
+## -----------------------------------------------------------------------------
+model_binom %>% 
+  summ(confint = TRUE, model.info = FALSE, exp = TRUE)
+
+## -----------------------------------------------------------------------------
 model_binom %>%
-  glm_coef(labels = model_labels(model_binom))
+  glm_coef(labels = model_labels(model_binom)) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_binom), font_size = 9)
 
 ## -----------------------------------------------------------------------------
 model_binom %>%
@@ -126,26 +146,51 @@ bdendo <- bdendo %>%
   )
 
 ## -----------------------------------------------------------------------------
-bdendo %>%
+t1 = bdendo %>%
+  filter(est == "Oestrogen") %>%
   mutate(
     cancer = relevel(cancer, ref = "Case"),
-    est = relevel(est, ref = "Oestrogen"),
     gall = relevel(gall, ref = "GBD")
   ) %>%
   copy_labels(bdendo) %>%
-  cross_tab(cancer ~ est + gall) %>%
-  theme_article()
+  cross_tab(cancer ~ gall,
+            label = "Oestrogen users")
+
+t2 = bdendo %>%
+  filter(est == "No oestrogen") %>%
+  mutate(
+    cancer = relevel(cancer, ref = "Case"),
+    gall = relevel(gall, ref = "GBD")
+  ) %>%
+  copy_labels(bdendo) %>%
+  cross_tab(cancer ~ gall,
+            label = "Non-oestrogen users")
+
+rbind(t1, t2) %>%
+  theme_pubh(c(3, 6, 9))
 
 ## -----------------------------------------------------------------------------
-library(survival)
-model_clogit <- clogit(cancer == 'Case'  ~ est * gall + strata(set), data = bdendo)
+bdendo %>%
+  gf_percents(~ cancer|gall, fill = ~ est, position = "dodge", alpha = 0.6) %>%
+  gf_labs(
+    y = "Percent",
+    x = "",
+    fill = ""
+  )
+
+## -----------------------------------------------------------------------------
+require(survival, quietly = TRUE)
+model_clogit <- clogit(cancer == 'Case' ~ est * gall + strata(set), data = bdendo)
 
 model_clogit %>%
   glm_coef(labels = c("Oestrogen/No oestrogen", "GBD/No GBD",
-                      "Oestrogen:GBD Interaction")) 
+                      "Oestrogen:GBD Interaction")) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_clogit), font_size = 9)
 
 ## -----------------------------------------------------------------------------
-require(ggeffects)
+require(ggeffects, quietly = TRUE)
 bdendo_pred <- ggemmeans(model_clogit, terms = c('gall', 'est'))
 
 ## -----------------------------------------------------------------------------
@@ -153,9 +198,9 @@ bdendo_pred %>%
   gf_pointrange(predicted + conf.low + conf.high ~ x|group, col = ~ x) %>%
   gf_labs(y = "P(cancer)", x = "", col = get_label(bdendo$gall))
 
-## -----------------------------------------------------------------------------
-library(ordinal)
-data(housing, package = "MASS")
+## ----message=FALSE------------------------------------------------------------
+require(MASS, quietly = TRUE)
+data(housing)
 housing <- housing %>%
   var_labels(
     Sat = "Satisfaction",
@@ -165,30 +210,33 @@ housing <- housing %>%
     )
 
 ## -----------------------------------------------------------------------------
-model_clm <- clm(Sat ~ Infl + Type + Cont, weights = Freq, data = housing)
+model_ord <- polr(Sat ~ Infl + Type + Cont, weights = Freq, data = housing, Hess = TRUE)
 
 ## -----------------------------------------------------------------------------
-model_clm %>%
-  glm_coef(labels = model_labels(model_clm, intercept = FALSE))
+model_ord %>%
+  glm_coef(labels = model_labels(model_ord, intercept = FALSE)) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_ord), font_size = 9)
 
 ## -----------------------------------------------------------------------------
-model_clm %>%
+model_ord %>%
   plot_model(type = "pred", terms = c("Infl", "Cont"), 
            dot.size = 1, title = "") %>%
   gf_theme(axis.text.x = element_text(angle = 45, hjust = 1))
 
 ## -----------------------------------------------------------------------------
-model_clm %>%
+model_ord %>%
   plot_model(type = "pred", terms = c("Infl", "Type"), 
            dot.size = 1, title = "") %>%
   gf_theme(axis.text.x = element_text(angle = 45, hjust = 1))
 
 ## -----------------------------------------------------------------------------
-emmip(model_clm, Infl ~ Type |Cont) %>%
+emmip(model_ord, Infl ~ Type |Cont) %>%
   gf_labs(x = "Type of rental", col = "Perceived influence")
 
 ## -----------------------------------------------------------------------------
-data(quine, package = "MASS")
+data(quine)
 levels(quine$Eth) <- c("Aboriginal", "White")
 levels(quine$Sex) <- c("Female", "Male")
 
@@ -200,7 +248,7 @@ quine <- quine %>%
     Age = "Age group"
     )
 
-## -----------------------------------------------------------------------------
+## ----message=FALSE------------------------------------------------------------
 quine %>%
   group_by(Eth, Sex, Age) %>%
   summarise(
@@ -209,13 +257,22 @@ quine %>%
     SD = sd(Days, na.rm = TRUE),
     Median = median(Days, na.rm = TRUE),
     CV = rel_dis(Days)
-  ) 
+  ) %>%
+  as_hux() %>% theme_pubh(1)
+
+## -----------------------------------------------------------------------------
+quine %>%
+  box_plot(Days ~ Age|Sex, fill = ~ Eth) %>%
+  axis_labs() %>% gf_labs(fill = "")
 
 ## -----------------------------------------------------------------------------
 model_pois <- glm(Days ~ Eth + Sex + Age, family = poisson, data = quine)
 
 model_pois %>%
-  glm_coef(labels = model_labels(model_pois), se_rob = TRUE)
+  glm_coef(labels = model_labels(model_pois), se_rob = TRUE) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_pois), font_size = 9)
 
 ## -----------------------------------------------------------------------------
 model_pois %>% glance()
@@ -223,12 +280,14 @@ model_pois %>% glance()
 ## -----------------------------------------------------------------------------
 deviance(model_pois) / df.residual(model_pois)
 
-## -----------------------------------------------------------------------------
-library(MASS)
+## ----message=FALSE------------------------------------------------------------
 model_negbin <- glm.nb(Days ~ Eth + Sex + Age, data = quine)
 
 model_negbin %>%
-  glm_coef(labels = model_labels(model_negbin), se_rob = TRUE) 
+  glm_coef(labels = model_labels(model_negbin), se_rob = TRUE)  %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_negbin), font_size = 9)
 
 ## -----------------------------------------------------------------------------
 model_negbin %>% glance()
@@ -246,7 +305,8 @@ emmip(model_negbin, Eth ~ Age|Sex) %>%
   gf_labs(y = "Number of absent days", x = "Age group", col = "Ethnicity")
 
 ## -----------------------------------------------------------------------------
-multiple(model_negbin, ~ Age|Eth)$df 
+multiple(model_negbin, ~ Age|Eth)$df %>%
+  as_hux() %>% theme_pubh(1)
 
 ## -----------------------------------------------------------------------------
 multiple(model_negbin, ~ Age|Eth)$fig_ci %>%
@@ -266,18 +326,27 @@ model_surv <- survreg(Surv(times, event) ~ rx, data = bladder)
 
 ## -----------------------------------------------------------------------------
 model_surv %>%
-  glm_coef(labels = c("Treatment: Thiotepa/Placebo", "Scale"), se_rob = TRUE)
+  glm_coef(labels = c("Treatment: Thiotepa/Placebo", "Scale"), se_rob = TRUE) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_surv), font_size = 9)
 
 ## -----------------------------------------------------------------------------
 model_exp <- survreg(Surv(times, event) ~ rx, data = bladder, dist = "exponential")
 
 ## -----------------------------------------------------------------------------
 model_exp %>%
-  glm_coef(labels = c("Treatment: Thiotepa/Placebo"), se_rob = TRUE)
+  glm_coef(labels = c("Treatment: Thiotepa/Placebo"), se_rob = TRUE) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_exp), font_size = 9)
 
 ## -----------------------------------------------------------------------------
 model_exp %>%
-  glm_coef(labels = c("Treatment: Thiotepa/Placebo"))
+  glm_coef(labels = c("Treatment: Thiotepa/Placebo")) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_exp), font_size = 9)
 
 ## -----------------------------------------------------------------------------
 model_exp %>%
@@ -289,7 +358,10 @@ model_cox <-  coxph(Surv(times, event) ~ rx, data = bladder)
 
 ## -----------------------------------------------------------------------------
 model_cox %>%
-  glm_coef(labels = c("Treatment: Thiotepa/Placebo"))
+  glm_coef(labels = c("Treatment: Thiotepa/Placebo")) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_cox), font_size = 9)
 
 ## -----------------------------------------------------------------------------
 model_cox %>%
@@ -297,9 +369,9 @@ model_cox %>%
            title = "") %>%
   gf_labs(x = "Treatment", title = "")
 
-## -----------------------------------------------------------------------------
-library(nlme)
-data(Orthodont)
+## ---- message=FALSE-----------------------------------------------------------
+require(lme4, quietly = TRUE)
+data(Orthodont, package = "nlme")
 
 ## -----------------------------------------------------------------------------
 Orthodont <- Orthodont %>%
@@ -309,21 +381,26 @@ Orthodont <- Orthodont %>%
     )
 
 ## -----------------------------------------------------------------------------
-model_lme <- lme(distance ~ Sex * I(age - mean(age, na.rm = TRUE)), random = ~ 1|Subject, 
-                 method = "ML", data = Orthodont)
+model_mix <- lmer(distance ~ Sex * age + (1|Subject), data = Orthodont)
 
 ## -----------------------------------------------------------------------------
-model_lme %>%
+model_mix %>%
+  summ(center = TRUE, confint = TRUE, model.info = FALSE)
+
+## -----------------------------------------------------------------------------
+model_mix %>%
+  center_mod() %>%
   glm_coef(labels = c(
-    "Constant", 
-    "Sex: female-male", 
-    "Age (years)",
+    model_labels(model_mix),
     "Sex:Age interaction"
-    )) 
+    )) %>%
+  as_hux() %>% set_align(everywhere, 2:3, "right") %>%
+  theme_pubh(1) %>%
+  add_footnote(get_r2(model_mix), font_size = 9)
 
 ## -----------------------------------------------------------------------------
-model_lme %>%
-  plot_model("pred", terms = age ~ Sex, 
+model_mix %>%
+  plot_model("eff", terms = age ~ Sex, 
            show.data = TRUE, jitter = 0.1, dot.size = 1.5) %>%
   gf_labs(y = get_label(Orthodont$distance), x = "Age (years)", title = "")
 
